clear all;
close all;
clc;
warning('off');

currentFolderName = pwd;                        % adresar ve kterem se script nachazi
paramMatrixName = 'paramMatrix';                % jmeno souboru s parametrizaci
localizationMRIName = 'localizationMRI';        % jmeno souboru s lokalizacemi z MRI

idx = strfind(currentFolderName, filesep);
nidx = length(idx);
patientFolder = strcat(currentFolderName(1:(idx(nidx)-1)), filesep, 'pacienti');            % adresar o uroven nize

try
    disp('Attempting to load file with data parameterization :');
    disp(strcat(pwd, filesep, paramMatrixName, '.mat'));
    load(paramMatrixName);

    disp('File successfully loaded.');
    display(' ');
    
    disp('Attempting to load file with TSC localizations :');
    disp(strcat(pwd, filesep, localizationMRIName, '.mat'));
    load(localizationMRIName);

    disp('File successfully loaded.');
    display(' ');
    
catch ME
    if strcmp(ME.identifier, 'MATLAB:load:couldNotReadFile')
        disp(ME.message);
    	rethrow(ME);
    end
end;

[nSets, nParams] = size(eval(paramMatrixName));         % pocet parametrizaci * pocet parametru
nMRI = length(eval(localizationMRIName));               % pocet MRI pacientu

disp('Getting model setting :');
paramVector = eval(strcat(paramMatrixName, '(', num2str(1), ',:)'));            % parametrizace celeho procesu

if nParams > 8
	detectorSetting = getDetectorSetting(paramVector(1:9));         % nastaveni detektoru
end;

if nParams > 10
    nasionToInion = paramVector(10);
    disp(['Distance between Nasion and Inion set as : ' num2str(nasionToInion)]);
    sigma = paramVector(11);
    disp(['Gaussinan covariance set as : ' num2str(sigma)]);
end;
display(' ');

testPatientFolder = strcat(currentFolderName(1:(idx(nidx)-1)), filesep, 'detektorTest');        % adresar se zdravimi pacienty, testovani detektoru

display('Computing false positive rate of the detector for the current setting :');

% cache s daty testovacich pacientu
testCache = [currentFolderName filesep 'cache' filesep 'test_data' filesep];

if exist([testCache, 'detectorFPRate.mat'], 'file')==2
    load([testCache, 'detectorFPRate.mat']);
    display('Results loaded from the cache.');
else
    detectorFPRate = getDetectorFPRate(detectorSetting, testPatientFolder);
    
    % uloz vysledky do cache
    [~,~,~] = mkdir(testCache);
    cd(testCache); 

    save('detectorFPRate', 'detectorFPRate');
    cd(currentFolderName);   
end;

% boxplot
% plot_script(detectorFPRate, 'box', 'Chybovost detektoru na datech zdravch novorozenc')

display('Done.');
display(' ');

% statistiky: hitMissVector = [ TP TN FP FN ]
hitMissVector_q_MRI_1 = [];
hitMissVector_q_MRI_2 = [];

hitMissVector_l_MRI_1 = [];
hitMissVector_l_MRI_2 = [];

k_weight = 1;

for i=1:nMRI
    currentFolder = strcat(patientFolder, filesep, localizationMRI(i).name);                    % adresar prave zpracovavaneho pacienta
    display(['Analysis for patient ' localizationMRI(i).name ' :']);
    display('Comparison of the first MRI immage with the detector results.');
    
    if isempty(localizationMRI(i).position_MRI_1)==1
        % prazdna clenska promenna
        display(['TCS position for patient ' localizationMRI(i).name ' not specified. Analysis skipped.']);
    else
        % neprazdna clenska promenna
        display('Costructing probability model.');
        probabilityModel = locationToWeightedElectrodes(localizationMRI(i).position_MRI_1, nasionToInion, sigma);
        display('Done.');
        
        % cache pro data pacientu
        patientCache = [currentFolderName filesep 'cache' filesep 'pacienti' filesep localizationMRI(i).name filesep 'MRI_1' filesep];
        
        if exist([patientCache, 'dataForPCA.mat'], 'file')==2
            % nacti vysledky z cache
            load([patientCache, 'dataForPCA.mat']);
            display('Results loaded from the cache.');
        else
            dataForPCA = recordListToPCA(localizationMRI(i).record_MRI_1, currentFolder, detectorSetting);
    
            % uloz vysledky do cache
            [~,~,~] = mkdir(patientCache);
            cd(patientCache); 

            save('dataForPCA', 'dataForPCA');
            cd(currentFolderName);
        end;
        
        pcPatientData = inversePCA(dataForPCA);

        [preparedData, w2] = getWeights(pcPatientData, detectorFPRate, k_weight);
        
%         subplot(2,1,1)
%         plot_script(w2, 'stem', 'Vhy dat pslun prvnmu men magnetickou rezonanc')
        
        % kvadrant
        resultingQDetector_MRI_1 = getDecision(preparedData, 'quadrant');
        resultingQModel_MRI_1 = getDecision(probabilityModel, 'quadrant');
        
        % lalok
        resultingLDetector_MRI_1 = getDecision(preparedData, 'lobe');
        resultingLModel_MRI_1 = getDecision(probabilityModel, 'lobe');
         
        % hitMissVector = [ TP TN FP FN ]
        temp_q = zeros(size(resultingQDetector_MRI_1));
        temp_l = zeros(size(resultingQDetector_MRI_1));

        for j=1:length(resultingQDetector_MRI_1(:, 1))
            temp_q(j, :) = getHitMiss(resultingQDetector_MRI_1(j, :), resultingQModel_MRI_1);
            temp_l(j, :) = getHitMiss(resultingLDetector_MRI_1(j, :), resultingLModel_MRI_1);
        end;
        
        hitMissVector_q_MRI_1 = [hitMissVector_q_MRI_1; temp_q];
        hitMissVector_l_MRI_1 = [hitMissVector_l_MRI_1; temp_l];
    end;

    
    display('Comparison of the second MRI immage with the detector results.');
    if isempty(localizationMRI(i).position_MRI_2)==1
        % prazdna clenska promenna
        display(['TCS position for patient ' localizationMRI(i).name ' not specified. Analysis skipped.']);
    else
        % neprazdna clenska promenna
        display('Costructing probability model.');
        probabilityModel = locationToWeightedElectrodes(localizationMRI(i).position_MRI_2, nasionToInion, sigma);
        display('Done.');
        
        % cache pro data pacientu
        patientCache = [currentFolderName filesep 'cache' filesep 'pacienti' filesep localizationMRI(i).name filesep 'MRI_2' filesep];
        
        if exist([patientCache, 'dataForPCA.mat'], 'file')==2
            % nacti vysledky z cache
            load([patientCache, 'dataForPCA.mat']);
            display('Results loaded from the cache.');
        else
            dataForPCA = recordListToPCA(localizationMRI(i).record_MRI_2, currentFolder, detectorSetting);
    
            % uloz vysledky do cache
            [~,~,~] = mkdir(patientCache);
            cd(patientCache); 

            save('dataForPCA', 'dataForPCA');
            cd(currentFolderName);
        end;

        pcPatientData = inversePCA(dataForPCA);
        
        [preparedData, w2] = getWeights(pcPatientData, detectorFPRate, k_weight);
        
%         subplot(2,1,2)
%         plot_script(w2, 'stem', 'Vhy dat pslun druhmu men magnetickou rezonanc')
              
        % kvadrant
        resultingQDetector_MRI_2 = getDecision(preparedData, 'quadrant');
        resultingQModel_MRI_2 = getDecision(probabilityModel, 'quadrant');
        
        % lalok
        resultingLDetector_MRI_2 = getDecision(preparedData, 'lobe');
        resultingLModel_MRI_2 = getDecision(probabilityModel, 'lobe');
        
        % hitMissVector = [ TP TN FP FN ]
        temp_q = zeros(size(resultingQDetector_MRI_2));
        temp_l = zeros(size(resultingQDetector_MRI_2));
        
        for j=1:length(resultingQDetector_MRI_2(:, 1))
            temp_q(j, :) = getHitMiss(resultingQDetector_MRI_2(j, :), resultingQModel_MRI_2);
            temp_l(j, :) = getHitMiss(resultingLDetector_MRI_2(j, :), resultingLModel_MRI_2);
        end;
        
        hitMissVector_q_MRI_2 = [hitMissVector_q_MRI_2; temp_q];
        hitMissVector_l_MRI_2 = [hitMissVector_l_MRI_2; temp_l];   
    end;
    
    display(' ');  
end;


for k=1:length(hitMissVector_q_MRI_1(:,1))
    % Sensitivity
    result_q_MRI_1(k, 1) = hitMissVector_q_MRI_1(k, 1)/(hitMissVector_q_MRI_1(k, 1) + hitMissVector_q_MRI_1(k, 4));
    % Specificity
    result_q_MRI_1(k, 2) = hitMissVector_q_MRI_1(k, 2)/(hitMissVector_q_MRI_1(k, 2) + hitMissVector_q_MRI_1(k, 3));
    % PPV
    result_q_MRI_1(k, 3) = hitMissVector_q_MRI_1(k, 1)/(hitMissVector_q_MRI_1(k, 1) + hitMissVector_q_MRI_1(k, 3));
    % Accuracy
    result_q_MRI_1(k, 4) = (hitMissVector_q_MRI_1(k, 1) + hitMissVector_q_MRI_1(k, 2))/4;
end;

for k=1:length(hitMissVector_q_MRI_2(:,1))
    % Sensitivity
    result_q_MRI_2(k, 1) = hitMissVector_q_MRI_2(k, 1)/(hitMissVector_q_MRI_2(k, 1) + hitMissVector_q_MRI_2(k, 4));
    % Specificity
    result_q_MRI_2(k, 2) = hitMissVector_q_MRI_2(k, 2)/(hitMissVector_q_MRI_2(k, 2) + hitMissVector_q_MRI_2(k, 3));
    % PPV
    result_q_MRI_2(k, 3) = hitMissVector_q_MRI_2(k, 1)/(hitMissVector_q_MRI_2(k, 1) + hitMissVector_q_MRI_2(k, 3));
    % Accuracy
    result_q_MRI_2(k, 4) = (hitMissVector_q_MRI_2(k, 1) + hitMissVector_q_MRI_2(k, 2))/4;
end;


for k=1:length(hitMissVector_l_MRI_1(:,1))
    % Sensitivity
    result_l_MRI_1(k, 1) = hitMissVector_l_MRI_1(k, 1)/(hitMissVector_l_MRI_1(k, 1) + hitMissVector_l_MRI_1(k, 4));
    % Specificity
    result_l_MRI_1(k, 2) = hitMissVector_l_MRI_1(k, 2)/(hitMissVector_l_MRI_1(k, 2) + hitMissVector_l_MRI_1(k, 3));
    % PPV
    result_l_MRI_1(k, 3) = hitMissVector_l_MRI_1(k, 1)/(hitMissVector_l_MRI_1(k, 1) + hitMissVector_l_MRI_1(k, 3));
    % Accuracy
    result_l_MRI_1(k, 4) = (hitMissVector_l_MRI_1(k, 1) + hitMissVector_l_MRI_1(k, 2))/8;
end;

for k=1:length(hitMissVector_l_MRI_2(:,1))
    % Sensitivity
    result_l_MRI_2(k, 1) = hitMissVector_l_MRI_2(k, 1)/(hitMissVector_l_MRI_2(k, 1) + hitMissVector_l_MRI_2(k, 4));
    % Specificity
    result_l_MRI_2(k, 2) = hitMissVector_l_MRI_2(k, 2)/(hitMissVector_l_MRI_2(k, 2) + hitMissVector_l_MRI_2(k, 3));
    % PPV
    result_l_MRI_2(k, 3) = hitMissVector_l_MRI_2(k, 1)/(hitMissVector_l_MRI_2(k, 1) + hitMissVector_l_MRI_2(k, 3));
    % Accuracy
    result_l_MRI_2(k, 4) = (hitMissVector_l_MRI_2(k, 1) + hitMissVector_l_MRI_2(k, 2))/8;
end;

% VYSLEDKY 
% prevod NaN na nuly
result_q_MRI_1(isnan(result_q_MRI_1)) = 0;
result_q_MRI_2(isnan(result_q_MRI_2)) = 0;
result_l_MRI_1(isnan(result_l_MRI_1)) = 0;
result_l_MRI_2(isnan(result_l_MRI_2)) = 0;


% save('result_q_MRI_1_11', 'result_q_MRI_1');
% save('result_q_MRI_2_11', 'result_q_MRI_2');
% save('result_l_MRI_1_11', 'result_l_MRI_1');
% save('result_l_MRI_2_11', 'result_l_MRI_2');


% roc_plot()

% p1=8, p2=14, p3=9, p4=6, p5=6, p6=9, p7=5, p8=0, p9=0
cluster_MRI_1 = [ 0 0 0 1 0 0 0 0 0 0  0 0 0 1.2 1.1 0 0 0 0;...
    0 0 0.2 0 0 0 0.1 0 0 0 0 0 0 0 0 0 0 0 0;...
    0 0 0 0 0 0 0 0 0 0 0.2 1.2 0 0 0 0 0 0 0;...
    0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 2.4;...
    0 0 0.6 0.2 0.1 0 0 0 0 0 0 0 0 0 0 0 0 0 0;...
    0 1.3 0 0 0 0 0 0 0 0 0 0 0 0 0 0.6 0 0 0;...
    0 0 0 0 0 1.2 0 0 0 0.6 0 0 0 0 0 0 0 0 0;...
    0 0 0 0 0 1.6 0 0 0 0 0 0 0 0 0 0 0 0 0;
    0 0 0 0 0 0 5 0 0 0 0 0 0 0 0 0 0 0 0;...
    0 0 0 1.8 0 0 0 0 0 0 2.61 0 0 0 0 0 0 2.5 0;...
    0 0 0 0 0 3 0 0 0 0 0 0 0 0 0 0 0 0 0;...
    0 2.9 0 0 0 0 0 0 0 0 7.7 0 0 0 6.7 0 0 0 0;...
    0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0;...
    0 0 0 0 0 0 0 0 0 0 0 1.2 0 0 1.36 0 0 0 0;...
    4.77 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0;...
    1.8 1.3 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0;...
    0 0 0 2.1 0.8 0 0 0 0 0 0 0 0 0 0 0 1.5 0 0;...
    0 0 0 0 0 0 0 0.7 0 0 1.5 0 0 0 0 0 0 0 0;...
    3 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0;...
    0 0.7 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0;...
    0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0;...
    1.6 1.5 0 0 0 0 0 0 0 0 0 0 0 0 3.76 0 0 0 0;...
    0 0 0 0 0 1.4 0 2.3 0 0 0 0 0 2.48 0 0 3.5 0 0;...
    0 0 0.2 0 0 0 0 0 0 0 0 0 0 1.64 0 0 0 0 0;...
    0 0 0 0 0 0 0 0 0 0 0 0 2.63 0 0 0 0 0 0;...
    0 0 0 0 0 0 0 0 0 0 0 0 0 0 4.97 0 0 0 0;...
    0 0 0 0.5 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0;...
    0 0 0 0 0 0 0 0 0 0 1.84 0 0 0 0 0 0 0 2.02;...
    3.5 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0;...
    0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 2.88;...
    0 2.1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 12.64;...
    0 0 0 0.1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0;...
    0 0 0 0 0 0 0 0 0 2.88 0 0 1 0 0 0 0 0 0;...
    0 0 0 0 0 0 0 0.7 0 0 0 0 0 1.08 0 0 0 0 0;...
    0 0 0 0 0.8 0 0 0 0 0 0 0 3.05 0 0 0 0 0 0;...
    2.2 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0;...
    0 0 0 0 0 0 4.2 0 0 0 1.1 0 0 0 0 0 0 0 0;...
    0 3.19 0 0 0 0 0 0 0 0 0 0 0 0 0 6.68 0 0 0;...
    0 0 0 0 0 0 0 0 0 0 0 0 0 1.13 0 0 0 0 0;...
    3.6 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0.8 0;...
    0 0 0.5 0 0 0 0 0 0.4 1.3 0 0 0 0 0 0 0 0 0;...
    0 0 0 0 0 0 0 0 0 1.8 0 0 0 0 0 1.5 0 0 0;...
    0.9 0 0 0 0 0 0 0 1.2 0 0 0 0 0 0 1.5 0 0 0;...
    0 0 0 0 0 0 0 0 0 0 0 0 0 1.3 0 0 0 0 0;...
    0 0.8 0 0 0 3.3 0 0 0 0 0 0 0 0 0 0 0.9 0 0;...
    0 0 0 0 0 0 0 0 0 0 0 0.6 3.04 0 3.24 0 0 0 0;...
    0 0 0 0 0 0 0 0 0 0 0 0 0 0 0.83 0 0 1.27 0;...
    0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0;...
    0 0 0 0 0 0 0 0 0 0 2.52 0 0 1.52 0 0 0 0 0;...
    0 0 0 1.2 0 0 0 0 0 0 0 4.82 5.7 2.28 0 0 0 0 0;...
    0 0 0 0 0 0 0 0 0 0 0.9 3.7 0 1.86 0 0 0 0 0;...
    0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0;...
    0 0 2.8 0 2.4 0 0 0 0 0 0 0.7 0 0 4.25 0 0 0 0;...
    0 0 0 0 0 0 0 0 0 0 0 0 3.3 0 17.2 9.14 0 0 0;...
    0 0.92 0 0 0.7 0 0 5.69 0 0 0 0 1.5 0 0 0 0 0 0;...
    0 0 0 0 0 0 0 3.5 0 0 0.8 0 0 0 0 0 0 3.86 2.9;...
    2.3 0 0 0 0 3.72 0 0 0 0 0 0 0 0 7.39 0 0 0 2.23];

% p1=7, p2=4, p3=2, p4=0, p5=0, p6=0, p7=7, p8=3, p9=5
cluster_MRI_2 = [0 0 0 0 0 0 1.1 0 0 0 0 0 0 0 0 0 0 0 0;...
    0 0 0.9 0 0 2 0 0 0 0 0 0 0 0 0 0 0 0 0;...
    0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 4.6 0 0.7 0;...
    0 0 0 2.7 0 0 0 0 0 1.4 0 0 0 0 0 0 0 0 0;...
    0 0 0 3 0 0 0 0 0 0 0 0 0 0 0 2.2 0 0 0;...
    0 0 0 0 0 0 0 0 0.5 0 0 0 0 3 0.4 0 0 0 0;...
    0 3.02 0 0 0 0 0 0 0 0 0 1.8 1.1 4.08 0 0 0 0 0;...
    0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1.8 0 0 0.73;...
    2.2 0 0 0.7 0 0 0 0 0 0 0 0 0 1.6 0 0.8 0 0 0;...
    0 0 0 0 0 0 0 0 0.5 0 0 0 0 0.7 1 0 0 0 0;...
    0 0 1.5 0 0 0 0 0 0 0 0 0 0 0 0 3.6 0 0 0;...
    0 0 0 0 0 0 0 0 0 0.1 0 0 0 0 0 0 0 0.2 0;...
    0 0 0 0 0 0 0 1.2 0 0 0 0.5 0 0 0 0 0 0 0;...
    1.6 0 1.7 0 0 0 0 0 0 0 0 0 0 0 9.75 0 0 0 0;...
    8.59 0.3 0 0 0 0 0 0 0 1.3 0 0 0 0 5.34 0 0 0 0;...
    0 0.5 0 0 0 0 0 0 0 0 1.95 0 0 0 3.42 0 0 0 0;...
    1.4 4.8 0 0 0 0.5 0 0 0 0 0 0 0 0 0 0 0 0 0;...
    0 0 0 0 0 0 1 0 3.9 9.9 0 0 1 0 0 0 0 0 0;...
    0 0 0 0 0 0 0 0 0 0 0 0 1.4 0 3.57 0 0 0 1.97;...
    0 0 0 0 0 0 0 0 0 4 0 0 0.3 0 0 0 0 0 0;...
    7.32 0 0 0 0 0 0 0 0 0 3.21 0.6 0 0 0 0 0 0 0;...
    0 0 0 2.3 1.4 0 0 0 0 0 0 1.1 0 0.7 0 0 0 0 0;...
    0 0 0 0 0 0 0 0 0 0 0 0 0 0 0.3 0 0 0 0;...
    0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0.9 0 0 0;...
    1.7 1.3 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0;...
    7.57 0 0 0 0 0 0 0 0 0 0 0 0 0 0 3.19 0 0 0;...
    1.2 0 0 0 0 0 0 0 0 0 0 0 0 0 2 0 0 0 1.2;...
    0 0 0 0 0 0 0 0 0 0.3 0 0 1.4 0 0 0 0 0 0];


for r=1:length(cluster_MRI_1(:,1))
    res_q_1(r, :) = getHitMiss(getDecision(cluster_MRI_1(r,:), 'quadrant'), getDecision(probabilityModel, 'quadrant'));
    % Sensitivity
    cluster_q_1(r, 1) = res_q_1(r, 1)/(res_q_1(r, 1) + res_q_1(r, 4));
    % Specificity
    cluster_q_1(r, 2) = res_q_1(r, 2)/(res_q_1(r, 2) + res_q_1(r, 3));
    % PPV
    cluster_q_1(r, 3) = res_q_1(r, 1)/(res_q_1(r, 1) + res_q_1(r, 3));
    % Accuracy
    cluster_q_1(r, 4) = (res_q_1(r, 1) + res_q_1(r, 2))/4;
    
    
    res_l_1(r,:) = getHitMiss(getDecision(cluster_MRI_1(r,:), 'lobe'), getDecision(probabilityModel, 'lobe'));
    % Sensitivity
    cluster_l_1(r, 1) = res_l_1(r, 1)/(res_l_1(r, 1) + res_l_1(r, 4));
    % Specificity
    cluster_l_1(r, 2) = res_l_1(r, 2)/(res_l_1(r, 2) + res_l_1(r, 3));
    % PPV
    cluster_l_1(r, 3) = res_l_1(r, 1)/(res_l_1(r, 1) + res_l_1(r, 3));
    % Accuracy
    cluster_l_1(r, 4) = (res_l_1(r, 1) + res_l_1(r, 2))/8;
end;

for r=1:length(cluster_MRI_2(:,1))
    res_q_2(r, :) = getHitMiss(getDecision(cluster_MRI_2(r,:), 'quadrant'), getDecision(probabilityModel, 'quadrant'));
    % Sensitivity
    cluster_q_2(r, 1) = res_q_2(r, 1)/(res_q_2(r, 1) + res_q_2(r, 4));
    % Specificity
    cluster_q_2(r, 2) = res_q_2(r, 2)/(res_q_2(r, 2) + res_q_2(r, 3));
    % PPV
    cluster_q_2(r, 3) = res_q_2(r, 1)/(res_q_2(r, 1) + res_q_2(r, 3));
    % Accuracy
    cluster_q_2(r, 4) = (res_q_2(r, 1) + res_q_2(r, 2))/4;
    
    
    res_l_2(r,:) = getHitMiss(getDecision(cluster_MRI_2(r,:), 'lobe'), getDecision(probabilityModel, 'lobe'));
    % Sensitivity
    cluster_l_2(r, 1) = res_l_2(r, 1)/(res_l_2(r, 1) + res_l_2(r, 4));
    % Specificity
    cluster_l_2(r, 2) = res_l_2(r, 2)/(res_l_2(r, 2) + res_l_2(r, 3));
    % PPV
    cluster_l_2(r, 3) = res_l_2(r, 1)/(res_l_2(r, 1) + res_l_2(r, 3));
    % Accuracy
    cluster_l_2(r, 4) = (res_l_2(r, 1) + res_l_2(r, 2))/8;
end;

% VYSLEDKY 
% prevod NaN na nuly
cluster_q_1(isnan(cluster_q_1)) = 0;
cluster_q_2(isnan(cluster_q_2)) = 0;
cluster_l_1(isnan(cluster_l_1)) = 0;
cluster_l_2(isnan(cluster_l_2)) = 0;


display('-------------------------');
display('Kvadrant MRI 1:');
tot_sen = std(cluster_q_1(:,1))
tot_spec = std(cluster_q_1(:,2))
tot_ppv = std(cluster_q_1(:,3))
tot_acc = std(cluster_q_1(:,4))
display('-------------------------');
display('Kvadrant MRI 2:');
tot_sen = std(cluster_q_2(:,1))
tot_spec = std(cluster_q_2(:,2))
tot_ppv = std(cluster_q_2(:,3))
tot_acc = std(cluster_q_2(:,4))
display('-------------------------');
display('Lalok MRI 1:');
tot_sen = std(cluster_l_1(:,1))
tot_spec = std(cluster_l_1(:,2))
tot_ppv = std(cluster_l_1(:,3))
tot_acc = std(cluster_l_1(:,4))
display('-------------------------');
display('Lalok MRI 2:');
tot_sen = std(cluster_l_2(:,1))
tot_spec = std(cluster_l_2(:,2))
tot_ppv = std(cluster_l_2(:,3))
tot_acc = std(cluster_l_2(:,4))
display('-------------------------');


% display('-------------------------');
% display('Kvadrant MRI 1:');
% tot_sen = mean(result_q_MRI_1(:,1))
% tot_spec = mean(result_q_MRI_1(:,2))
% tot_ppv = mean(result_q_MRI_1(:,3))
% tot_acc = mean(result_q_MRI_1(:,4))
% display('-------------------------');
% display('Kvadrant MRI 2:');
% tot_sen = mean(result_q_MRI_2(:,1))
% tot_spec = mean(result_q_MRI_2(:,2))
% tot_ppv = mean(result_q_MRI_2(:,3))
% tot_acc = mean(result_q_MRI_2(:,4))
% display('-------------------------');
% display('Lalok MRI 1:');
% tot_sen = mean(result_l_MRI_1(:,1))
% tot_spec = mean(result_l_MRI_1(:,2))
% tot_ppv = mean(result_l_MRI_1(:,3))
% tot_acc = mean(result_l_MRI_1(:,4))
% display('-------------------------');
% display('Lalok MRI 2:');
% tot_sen = mean(result_l_MRI_2(:,1))
% tot_spec = mean(result_l_MRI_2(:,2))
% tot_ppv = mean(result_l_MRI_2(:,3))
% tot_acc = mean(result_l_MRI_2(:,4))
% display('-------------------------');
% display('Done.');
% display(' ');