clear all;
close all;
clc;
warning('off');

currentFolderName = pwd;
paramMatrixName = 'paramMatrix';

idx = strfind(currentFolderName, filesep);
nidx = length(idx);
patientFolder = strcat(currentFolderName(1:(idx(nidx)-1)), filesep, 'pacienti');

patientList = dir(patientFolder);

% pocet pacientu ve slozce
[nPatients, ~] = size(patientList);


try
    disp('Attempting to load file with data parameterization :');
    disp(strcat(pwd, filesep, paramMatrixName, '.mat'));
    load(paramMatrixName);

    disp('File successfully loaded.');
    display(' ');
    
    % pocet parametrizaci * pocet parametru
    [nSets, nParams] = size(eval(paramMatrixName));

    % cyklus pres parametrizace
    for i=1:nSets
        % ziskani parametrizacniho vektoru ze vstupni matice
        paramVector = eval(strcat(paramMatrixName, '(', num2str(i), ',:)'));
        
        % prvnich 8 parametru = nastaveni detektoru
        if nParams > 8
            detectorSetting = getDetectorSetting(paramVector(1:9));
        end;
    
        % paramVector(10:n) dalsi hodnoty parametrizace

        display(char(strcat({'Run '}, num2str(i), {' out of '}, num2str(nSets), '.')));
        
        % cyklus pres pacienty ve slozce
        for j=3:nPatients
            % cesta k pacientovi a jmeno pacienta
            currentPatient = strcat(patientFolder, filesep, patientList(j).name);
            patientName = patientList(j).name;
            
            display('-----------------------------------------------------');
            display(char(strcat({'Patients name : '}, patientList(j).name)));
            display('-----------------------------------------------------');
            
            % seznam vsech zaznamu pro daneho pacienta
            recordList = dir(currentPatient);
    
            [nRecord, ~] = size(recordList);
    
            % cyklus pres zaznamy
            for k=3:nRecord
                % cesta k zaznamu a jeho jmeno
                currentRecord = strcat(currentPatient, filesep, recordList(k).name, ...
                    filesep, 'raw', filesep, 'interictal');
                recordDate = recordList(k).name;
                
                display(char(strcat({'Time of recording : '}, recordList(k).name)));
        
                matFileList = what(currentRecord);
        
                [nRecordDay, ~] = size(matFileList.mat);
        
                    for l=1:nRecordDay
                        fullFilePath = char(strcat(currentRecord, filesep, matFileList.mat(l)));
                        mfileName = matFileList.mat(l);

                        display(char(strcat({'Processing file : '}, matFileList.mat(l))));
                        
                        load(fullFilePath);
                        fs = floor(1/mean(diff(t)));
                        
                        % outputs:-----------------------------------------------------------------
                        % MARKER.d ... resampled signal "d" to 200 Hz
                        % MARKER.fs ... new sampling frequency
                        % MARKER.M ... zero matrix with same size as signal "d", where 1 indicate 
                        %              obviuos spike, 0.5 ambiguous
                        % disharges ... structure of multichannel event describes occurence of
                        %               spikes suddenly 
                        %           discharges.MV ... matrix of type (n x ch) 
                        %                             (1-obvious spike, 0.5-ambiguous)
                        %           discharges.MA ... matrix of max. amplitude of envelope above 
                        %                             backround (n x ch)
                        %           discharges.MP ... start position of multichannel event 
                        %           discharges.MD ... duration of event
                        %           discharges.MW ... statistical significance "CDF"
                        %           discharges.MPDF ... probability of occurence
                        % out ... structure describing each detected spike. Usefull for export to
                        %         GDF files using biosig toolbox (biosig.sourceforge.net)
                        %           out.pos ... position (second)
                        %           out.dur ... duration (second) - fixed 1/fs 
                        %           out.chan ... channel
                        %           out.con ... type (1-obvious 0.5-ambiguous)
                        %           out.weigth ... statistical significance "CDF"
                        %           out.pdf ... statistical significance "PDF"
                        
                        [MARKER, envelope, background, discharges, out]=spike_detector_hilbert_v16(d,fs,detectorSetting);
                        
                        % vypocet vah kanalu na zaklade detekci
                        channelWeight = sum(discharges.MV);
                        
                        % vytvoreni adresaru pro vysledky a ulozeni ve forme
                        % *.mat
                        NEWDIR = [filesep patientName filesep recordDate filesep];
                        [~,~,~] = mkdir(currentFolderName,NEWDIR);
                        cd([currentFolderName NEWDIR]);                    
                        
                        [~, name, ~] = fileparts(char(mfileName));
                        filename = [name '_p' num2str(i)];
                        save(filename, 'channelWeight');
                        
                    end;  
            end;
            display(' ');
        end;   
        cd(currentFolderName);
    end;
    
catch ME
    if strcmp(ME.identifier, 'MATLAB:load:couldNotReadFile')
        disp(ME.message);
    	rethrow(ME);
    end

end;















